@@ -1,6 +1,6 @@
 package Ubic::Admin::Setup;
 {
-  $Ubic::Admin::Setup::VERSION = '1.46';
+  $Ubic::Admin::Setup::VERSION = '1.47';
 }
 
 # ABSTRACT: this module handles ubic setup: asks user some questions and configures your system
@@ -388,7 +388,7 @@ sub setup {
                 print {$fh} @_ or die "Can't write to pipe: $!";
             };
             $printc->($old_crontab."\n");
-            $printc->("* * * * * ${crontab_env_fix}ubic-watchdog ubic.watchdog    >$log_dir/watchdog.log 2>$log_dir/watchdog.err.log\n");
+            $printc->("* * * * * ${crontab_env_fix}ubic-watchdog ubic.watchdog    >>$log_dir/watchdog.log 2>>$log_dir/watchdog.err.log\n");
             close $fh or die "Can't close pipe: $!";
         }
     }
@@ -412,6 +412,7 @@ sub setup {
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -420,7 +421,7 @@ Ubic::Admin::Setup - this module handles ubic setup: asks user some questions an
 
 =head1 VERSION
 
-version 1.46
+version 1.47
 
 =head1 DESCRPITION
 
@@ -482,4 +483,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
